beluga Base Reference
=====================

.. module:: beluga

Introduction
------------

Base Class Reference
--------------------

.. autoclass:: beluga.OCP

.. autofunction:: add_logger

.. autofunction:: bvp_algorithm

.. autofunction:: guess_generator

.. autofunction:: run_continuation_set

.. autofunction:: ocp2bvp
